:mod:`bdbcontrib.predictors.random_forest`: Random forest predictor
===================================================================

Incorporating random forests into BayesDB as a foreign predictor.

.. automodule:: bdbcontrib.predictors.random_forest
 :members:
